*********************************************************
********************* Analysis **************************
*********************************************************

clear
eststo clear
set more off
set mem 100m


* Table 1: Summary stats

file open T1 using Table1Column1.csv, replace write
file write T1 "Table 1: Summary Statistics - Column 1" _n
file close T1

use "Coded Dataset - Package Level.dta", clear
gen count = 1
drop if mi(first_contract_date)
collapse (sum) estimated_cost (count) packages=count, by(sanction_year state_id eproc_start_year)
gen log_estimated_cost = log(estimated_cost)
label var packages "Total projects"
label var log_estimated_cost "Log total budget"

estpost tabstat packages log_estimated_cost, statistics(mean sd count) columns(statistics) listwise

esttab using Table1Column1.csv, cells((mean(fmt(%4.3f)) count(fmt(0))) sd) title(State Level) collabels("Mean (SD)" "Obs.") unstack noobs nostar nonote nomtitle nonumber label append

use "Coded Dataset - Package Level.dta", clear
label var log_estimated_cost "Log estimated cost"
label var contracts_in_package "Contracts in package"
label var log_contract_value "Log total value of contracts in package"
label var first_quality_grade "Satisfactory quality at first inspection"

estpost tabstat log_estimated_cost contracts_in_package log_contract_value first_quality_grade if !mi(log_estimated_cost) & !mi(log_contract_value), statistics(mean sd count) columns(statistics) 

esttab using Table1Column1.csv, cells((mean(fmt(%4.3f)) count(fmt(0))) sd) title(Package Level) collabels(none) unstack noobs nostar nonote nomtitle nonumber label append

use "Coded Dataset - Contract Level.dta", clear
label var log_contract_value "Log contract value"
label var log_payment_on_completed "Log final payment"
label var days_late "Completion delay (days)"
label var total_bids "Number of firms bidding"
label var same_district "Winner from same district/prov."
label var time_overrun_ratio "Time overrun ratio"
label var late "Late" 

estpost tabstat log_contract_value log_payment_on_completed days_late total_bids same_district time_overrun_ratio late, statistics(mean sd count) columns(statistics) 

esttab using Table1Column1.csv, cells((mean(fmt(%4.3f)) count(fmt(0))) sd) title(Contract Level) collabels(none) unstack noobs nostar nonote nomtitle nonumber label append

local cutoffdate = date("1-1-2002", "MDY")
egen contractor_present_in_00_or_01 = rowmax(contractor_present_in_00 contractor_present_in_01)
label var contractor_present_in_00_or_01 "Winner won in first year"
estpost tabstat contractor_present_in_00_or_01 if contract_date >= date("1-1-2002", "MDY"), statistics(mean sd count) columns(statistics) listwise

esttab using Table1Column1.csv, eqlabels(none) cells((mean(fmt(%4.3f)) count(fmt(0))) sd) collabels(none) unstack noobs nostar nonote nomtitle nonumber label append


* Table 2: Identification Check

use "Coded Dataset - Package Level.dta", clear

gen count = 1
drop if mi(first_contract_date)
collapse (sum) estimated_cost road_length (count) packages=count, by(sanction_year state_id eproc_start_year)

gen log_estimated_cost = log(estimated_cost)
gen log_road_length = log(road_length)
gen eproc = !(sanction_year < eproc_start_year) if eproc_start_year != . & sanction_year != .
label var eproc "E-procurement"
label var packages "Number of projects in state-year"
label var log_estimated_cost "Log (total estimated cost at state-year)"

xi: reg log_estimated_cost eproc log_road_length i.sanction_year i.state_id, cluster(state_id)
tabstat log_estimated_cost if eproc == 0, s(mean sd) save
mat R = r(StatTotal)
eststo, add(mean R[1,1] sd R[2,1])

xi: reg packages eproc log_estimated_cost log_road_length i.sanction_year i.state_id, cluster(state_id)
tabstat packages if eproc == 0, s(mean sd) save
mat R = r(StatTotal)
eststo, add(mean R[1,1] sd R[2,1])

esttab using Table2Panel1.csv, replace keep(eproc) scalars("mean Mean Dep. Var. (Non-Eproc)" "sd S.D.") se star(* 0.10 ** 0.05 *** 0.01) title("Table 2: Budget Impact - Panel A") nonote nonumbers label obslast csv
eststo clear


* Table 3: Contract Process

use "Coded Dataset - Contract Level.dta", clear
label var eproc "E-procurement"
label var total_bids "Number of firms bidding"
label var same_district "Winner from same province/district"

xi: reg total_bids eproc log_estimated_cost log_road_length i.state_id i.nit_year, robust
tabstat total_bids if eproc == 0, s(mean sd) save
mat R = r(StatTotal)
eststo, add(mean R[1,1] sd R[2,1])
**** STANDARD ERROR FOR TABLE 3 PANEL 1 COLUMN 4 IS CALCULATED AS P-VALUE USING
**** WILD BOOTSTRAPPING AND IS SAVED SEPARATELY IN Table3Panel1Column4PValue.txt
**** THE STANDARD ERROR SAVED BY THIS CODE IS INCORRECT

xi: reg same_district eproc log_road_length log_estimated_cost i.state_id i.nit_year, cluster(state_id)
tabstat same_district if eproc == 0, s(mean sd) save
mat R = r(StatTotal)
eststo, add(mean R[1,1] sd R[2,1])

local cutoffdate = date("1-1-2002", "MDY")
egen contractor_present_in_00_or_01 = rowmax(contractor_present_in_00 contractor_present_in_01)
label var contractor_present_in_00_or_01 "Winner in first year"
xi: reg contractor_present_in_00_or_01 eproc log_road_length log_estimated_cost i.state_id i.nit_year if contract_date >= date("1-1-2002", "MDY"), cluster(state_id)
tabstat contractor_present_in_00_or_01 if eproc == 0 & contract_date >= `cutoffdate', s(mean sd) save
mat R = r(StatTotal)
eststo, add(mean R[1,1] sd R[2,1])

esttab using Table3Panel1.csv, replace keep(eproc) scalars("mean Mean Dep. Var. (Non-Eproc)" "sd S.D.") se star(* 0.10 ** 0.05 *** 0.01) title("Table 3: Contract Process - Panel A") nonote nonumbers label obslast csv
eststo clear

include Subroutines/wildbootstrapping.do


* Table 4: Prices and project execution

use "Coded Dataset - Package Level.dta", clear
ren any_eproc eproc
label var eproc "E-procurement"

xi: reg log_contract_value eproc log_estimated_cost log_road_length i.state_id i.sanction_year, cluster(state_id)
tabstat log_contract_value if eproc == 0, s(mean sd) save
mat R = r(StatTotal)
eststo, add(mean R[1,1] sd R[2,1])

xi: reg log_payment_on_completed eproc log_estimated_cost log_road_length i.state_id i.sanction_year, cluster(state_id)
tabstat log_payment_on_completed if eproc == 0, s(mean sd) save
mat R = r(StatTotal)
eststo, add(mean R[1,1] sd R[2,1])

use "Coded Dataset - Contract Level.dta", clear
label var eproc "E-procurement"

xi: reg late eproc log_road_length log_estimated_cost i.state_id i.nit_year, cluster(state_id)
tabstat late if eproc == 0, s(mean sd) save
mat R = r(StatTotal)
eststo, add(mean R[1,1] sd R[2,1])

xi: reg time_overrun_ratio eproc log_road_length log_estimated_cost i.state_id i.nit_year, cluster(state_id)
tabstat time_overrun_ratio if eproc == 0, s(mean sd) save
mat R = r(StatTotal)
eststo, add(mean R[1,1] sd R[2,1])

use "Coded Dataset - Package Level.dta", clear
ren any_eproc eproc
label var eproc "E-procurement"

xi: reg first_quality_grade eproc log_estimated_cost log_road_length complete_at_first_insp i.monitor_id i.first_insp_year i.state_id i.sanction_year, cluster(state_id)
tabstat first_quality_grade if eproc == 0, s(mean sd) save
mat R = r(StatTotal)
eststo, add(mean R[1,1] sd R[2,1])

xi: reg worst_quality_grade eproc log_estimated_cost log_road_length i.state_id i.sanction_year, cluster(state_id)
tabstat worst_quality_grade if eproc == 0, s(mean sd) save
mat R = r(StatTotal)
eststo, add(mean R[1,1] sd R[2,1])

drop if all_complete_at_insp != 1

xi: reg first_quality_grade eproc log_estimated_cost log_road_length i.monitor_id i.first_insp_year i.state_id i.sanction_year, cluster(state_id)
tabstat first_quality_grade if eproc == 0, s(mean sd) save
mat R = r(StatTotal)
eststo, add(mean R[1,1] sd R[2,1])

xi: reg worst_quality_grade eproc log_estimated_cost log_road_length i.state_id i.sanction_year, cluster(state_id)
tabstat worst_quality_grade if eproc == 0, s(mean sd) save
mat R = r(StatTotal)
eststo, add(mean R[1,1] sd R[2,1])

esttab using Table4Panel1.csv, replace keep(eproc) scalars("mean Mean Dep. Var. (Non-Eproc)" "sd S.D.") se star(* 0.10 ** 0.05 *** 0.01) title("Table 4: Prices and project execution - Panel A") nonote nonumbers label obslast csv ///
	mlabels("Log contract value" "Log final payment" "Late completion" "Time overrun ratio" "First quality grade" "First quality grade (cond. on completion)" "Minimum across quality grades" "Minimum across quality grades (cond. on completion)")
eststo clear



* Table 5: Two-stage contractor FE regressions 

use "Coded Dataset - Contract Level.dta", clear
label var eproc "E-procurement"

keep if contracts_in_package == 1

xi: fese log_contract_value eproc log_road_length log_estimated_cost i.nit_year, absorb(contractor_id_at_large) s(contractor_lcv_avg)
eststo: xi: reg contractor_lcv_avgb eproc log_road_length log_estimated_cost i.nit_year i.state_id [aw=1/contractor_lcv_avgse^2], cluster(state_id)

xi: fese log_payment_on_completed eproc log_road_length log_estimated_cost i.nit_year, absorb(contractor_id_at_large) s(contractor_lpoc_avg)
eststo: xi: reg contractor_lpoc_avgb eproc log_road_length log_estimated_cost i.nit_year i.state_id [aw=1/contractor_lpoc_avgse^2], cluster(state_id)

xi: fese late log_road_length eproc log_estimated_cost i.nit_year, absorb(contractor_id_at_large) s(contractor_l_avg)
eststo: xi: reg contractor_l_avgb eproc log_road_length log_estimated_cost i.nit_year i.state_id [aw=1/contractor_l_avgse^2], cluster(state_id)

xi: fese time_overrun_ratio eproc log_road_length log_estimated_cost i.nit_year, absorb(contractor_id_at_large) s(contractor_tor_avg)
eststo: xi: reg contractor_tor_avgb eproc log_road_length log_estimated_cost i.nit_year i.state_id [aw=1/contractor_tor_avgse^2], cluster(state_id)

xi: fese first_quality_grade eproc log_road_length log_estimated_cost i.nit_year, absorb(contractor_id_at_large) s(contractor_fqg_avg)
eststo: xi: reg contractor_fqg_avgb eproc log_road_length log_estimated_cost i.nit_year i.state_id [aw=1/contractor_fqg_avgse^2], cluster(state_id)

xi: fese worst_quality_grade eproc log_road_length log_estimated_cost i.nit_year, absorb(contractor_id_at_large) s(contractor_wqg_avg)
eststo: xi: reg contractor_wqg_avgb eproc log_road_length log_estimated_cost i.nit_year i.state_id [aw=1/contractor_wqg_avgse^2], cluster(state_id)

keep if complete_at_first_insp == 1
drop contractor_fqg* contractor_wqg_avg*

xi: fese first_quality_grade eproc log_road_length log_estimated_cost i.nit_year, absorb(contractor_id_at_large) s(contractor_fqg_avg)
eststo: xi: reg contractor_fqg_avgb eproc log_road_length log_estimated_cost i.nit_year i.state_id [aw=1/contractor_fqg_avgse^2], cluster(state_id)

xi: fese worst_quality_grade eproc log_road_length log_estimated_cost i.nit_year, absorb(contractor_id_at_large) s(contractor_wqg_avg)
eststo: xi: reg contractor_wqg_avgb eproc log_road_length log_estimated_cost i.nit_year i.state_id [aw=1/contractor_wqg_avgse^2], cluster(state_id)

esttab using Table5Panel1.csv, replace keep(eproc) se star(* 0.10 ** 0.05 *** 0.01) title("Table 5: Two-Stage Contractor FE Regressions - Panel A") nonote nonumbers label obslast csv ///
	mlabels("Log contract value" "Log final payment" "Late completion" "Time overrun ratio" "First quality grade" "First quality grade (cond. on completion)" "Minimum across quality grades" "Minimum across quality grades (cond. on completion)")
eststo clear


* Appendix Tables

use "Coded Dataset - Contract Level.dta", clear

collapse (mean) contract_value eproc_start_year, by(nit_year state_id)

gen ln_avg_contract_value = ln(contract_value)

gen ln_cvtmp_01 = ln_avg_contract_value if nit_year <= 2001
bysort state_id: egen ln_cv_01 = min(ln_cvtmp_01)
gen ln_cvtmp_02 = ln_avg_contract_value if nit_year == 2002
bysort state_id: egen ln_cv_02 = min(ln_cvtmp_02)
	
gen ln_cv_diff = ln_cv_02 - ln_cv_01

keep state_id ln_cv_02 ln_cv_01 eproc_start_year ln_cv_diff
duplicates drop

label var eproc_start_year "E-procurement"
label var ln_cv_diff "Difference in log contract value"

reg ln_cv_diff eproc_start_year if eproc_start_year > 2002, robust
tabstat ln_cv_diff, s(mean sd) save
mat R = r(StatTotal)
eststo, add(mean R[1,1] sd R[2,1])

esttab using AppendixTable1Panel1.csv, replace keep(eproc_start_year) scalars("mean Mean Dep. Var. (Non-Eproc)" "sd S.D.") se star(* 0.10 ** 0.05 *** 0.01) title("Appendix Table 1 - Panel A") nonote nonumbers label obslast csv
eststo clear

* Figure 1
include Subroutines/UPbidding.do

* Figure 2
include Subroutines/map.do

