clear

*********************************************************
********************* Merge Data ************************
*********************************************************

*********************************************************
********************** SETTINGS **************************
*********************************************************

set more off
set mem 700m
tempfile MergeInProcess
tempfile TenderingDetails
tempfile AgreementDetails
tempfile WorkAwardDetailsMain
tempfile WorkAwardPopups
tempfile StatewiseSanctions
tempfile DelayedExecution
tempfile DelayedWorkAwarding
tempfile QualityMonitoring
tempfile AP1
tempfile AP2
tempfile AP3
tempfile CG
tempfile KN
tempfile UP


**************** TENDERING DETAILS ************************
*********************************************************

insheet using Data/Website/TenderingDetails.csv, names clear

* Renames
rename sanctionyear sanction_year
rename contractorname contractor
rename companyname company
rename nitno nit_number

* Convert to STATA dates and change odd values to missing
gen contract_date = date(dateofworkorder, "DMY")
gen nit_date = date(dateofnit, "DMY")
gen agreement_date = date(dateofagreement, "DMY")
drop dateofworkorder dateofnit dateofagreement
format %td contract_date nit_date agreement_date
replace contract_date = . if contract_date == 0 | contract_date < td(01jan2000)
replace nit_date = . if nit_date == 0 | nit_date < td(01jan2000)
replace agreement_date = . if agreement_date == 0 | agreement_date < td(01jan2000)

* Cleaning
replace contractor = trim(contractor)
replace company = trim(company)
replace company = "" if ( company == "International Wrie Prodect" | company == "General Engineering Company" ) & package == "RJWB0903" & contract_date == 17030
replace company = "" if ( company == "Rural Works Department" | company == "Public Works Department" ) & package == "AR1502" & contract_date == 14712
replace company = "" if ( company == "Public Works Department" | company == "Rural Works Department" ) & package == "BMS" & contract_date == 14712
replace company = "" if ( company == "Public Works Department" | company == "Rural Works Department" ) & package == "AR1503" & contract_date == 15096
replace company = "Ms Shri Nakoda Const Co" if company == "Nakoda Const Co"
replace company = "Mukesh Kumar Tailor" if company == "Mukesh Kumar Taiolr"
replace company = "KOTHAGHAR Construction and Consultancy Pvt. Limited." if company == "KOTHAGHAR Construction & Consultancy Pvt Ltd"
replace company = "Paramanda Pradhan" if company == "Parmanda Pradhan"
replace company = "Pawan Kumar Jain" if company == "M/S Pawan Kumar Jain"
replace company = "M/s Shiva Enterprises" if company == "M/s Shiva Enterprises,"
replace company = "Shri Rajendra Kumar Kalal" if company == "Shri Rajendra Kumar"
replace company = "Ram Narayan" if company == "Shri Ram Narayan"
replace company = "M/s Pareta Associates" if company == "Pareta Asssociates Kota Rajasthan"
replace company = "Rahul Engineers" if company == "Ms Rahul Engineers Udaipur"
replace company = "Panwar Construction" if company == "Ms Panwar Construction"

* Identify missings
replace nit_number = "" if nit_number == "-"
replace contractor = "" if contractor == "-"
replace company = "" if company == "-"

* Dropping blank packages, packages with no information, and duplicates
drop if package == "" | package == "-" | package == "#REF!" | package == "NIL"
drop if nit_date == . & contractor == "" &  company == "" & nit_number == "" & contract_date == . & agreement_date == . 
duplicates drop

destring, replace
compress
save `TenderingDetails', replace

**************** AGREEMENT DETAILS ************************
*********************************************************

insheet using Data/Website/AgreementDetails.csv, clear

* Renames
rename sanctionyear sanction_year
rename nitno nit_number
rename tendervalueinlakhs contract_value
rename agreementno agreement_number

* Convert to STATA dates and change odd values to missing
gen contract_date = date(dateofworkorder, "DMY")
gen completiondue_date = date(dateofcompletion, "DMY")
gen agreement_date = date(dateofagreement, "DMY")
drop dateofworkorder dateofcompletion dateofagreement
format %td contract_date completiondue_date agreement_date
replace contract_date = . if contract_date == 0 | contract_date < td(01jan2000)
replace completiondue_date = . if completiondue_date == 0 | completiondue_date < td(01jan2000)
replace agreement_date = . if agreement_date == 0 | agreement_date < td(01jan2000)

* Split contractor name from its ID
split contractorname, parse( "(ID -" )
drop contractorname
rename contractorname1 contractor
rename contractorname2 contractor_id
replace contractor = trim(contractor)
replace contractor_id = subinstr(contractor_id, ")", "",.)

* Cleaning
replace nit_number = subinstr(nit_number, "–", "-", .)
replace contractor = trim(contractor)
replace contractor_id = "682" if contractor == "Patit Paban Mohapatra" & substr(package, 1, 2) == "OR"
replace contractor_id = "421" if contractor == "Paritosh Roy" & substr(package, 1, 2) == "WB"

* Identify missings
replace nit_number = "" if nit_number == "-"
replace contractor = "" if contractor == "-"
replace contract_value = . if contract_value == 0
	
* Dropping blank packages and duplicates
drop if package == "" | package == "-" | package == "#REF!" | package == "NIL"
duplicates drop

destring, replace
compress
save `AgreementDetails', replace

************** WORK AWARD DETAILS ************************
*********************************************************

insheet using Data/Website/WorkAwardDetailsMain.csv, clear

* Renames
rename sanctionyear sanction_year
rename nameofcontractor company
rename dateofclearance clearance_date
rename contractvalue contract_value
rename valueofworkdone work_value
rename paymentmade payment
rename dateoffinalbill final_bill_date

* Convert to STATA dates and change odd values to missing
gen nit_date = date(dateofnit, "DMY")
gen contract_date = date(dateofcontract, "DMY")
gen completiondue_date = date(duedateofcompletion, "DMY")
gen actualcompletion_date = date(actualdateofcompletion, "MY")
drop dateofnit dateofcontract duedateofcompletion actualdateofcompletion
format %td nit_date contract_date completiondue_date actualcompletion_date
replace nit_date = . if nit_date == 0 | nit_date < td(01jan2000)
replace contract_date = . if contract_date == 0 | contract_date < td(01jan2000)
replace completiondue_date = . if completiondue_date == 0 | completiondue_date < td(01jan2000)
replace actualcompletion_date = . if actualcompletion_date == 0 | actualcompletion_date < td(01jan2000)

replace company = trim(company)

* Identify missings
replace company = "" if company == "-"
replace contract_value = . if contract_value == 0

* Dropping blank packages and duplicates
drop if package == "" | package == "-" | package == "#REF!" | package == "NIL"
duplicates drop

destring, replace
compress
save `WorkAwardDetailsMain', replace

*************** WORK AWARD POPUPS ************************
*********************************************************

insheet using Data/Website/WorkAwardPopups.csv, clear

* Renames
rename lengthofroadkm road_length
rename totalcostinlakhs estimated_cost_less_protect
rename completionstatus completion_status
rename preparatoryworkkm prep_work_length
rename earthworkkm earch_work_length
rename subbasekm subbase_length
rename basecoursekm base_course_length
rename surfacecoursekm surface_course_length
rename roadsigns road_signs_count
rename cdworks cd_works
rename miscellaneous misc
rename totalworkdone completion_percent
rename costofworkdoneinlakhs work_value
rename amountpaidinlakhs payment
rename sanctionyear sanction_year

replace estimated_cost_less_protect = round(estimated_cost_less_protect, 0.01)

* Calculate total and completed roads based on the number listed in each popup
gen group = 1
gen complete = (completion_status == "Complete")
replace group = group[_n-1] + (srno[_n-1]=="Total") if _n != 1
bysort group: gen sanctioned_road_count = _N - 1
by group: egen completed_road_count = sum(complete)

* Drop all but aggregated observations and unused variables
keep if srno == "Total"
drop srno nameofblock nameofroad group complete completion_status completion_percent

* Dropping blank packages and duplicates
drop if package == "" | package == "-" | package == "#REF!" | package == "NIL"
duplicates drop

destring, replace
compress
save `WorkAwardPopups', replace

**************** STATEWISE SANCTIONS **********************
*********************************************************

insheet using Data/Website/StatewiseSanctions.csv, clear

* Renames
rename sanctionyear sanction_year
rename noofroads cleared_road_count
rename collaborationworldbank joint_WB
rename collaborationadb joint_ADB
rename collaborationregularpmgsy joint_PMGSY
rename noofhabitationscovered habitations_covered_count
rename pavementlengthinkms road_length
rename costrsinlks est_subcost
rename perkmcostrsinlks est_cost_per_km
rename noofcdworks cd_works_count
rename costofcdworksrsinlks cd_works_est_cost
rename nooflongspanbridgesworks ls_bridges_count
rename costoflongspanbridgesrsinlks ls_bridges_est_cost
rename protectionworksrsinlks protection_works_est_cost
rename otherworksrsinlks other_works_est_cost
rename totalcostrsinlks estimated_cost
rename statecostrsinlks est_state_contribution

gen estimated_cost_less_protect = round(estimated_cost - protection_works_est_cost, 0.01)

* Keeping only the totals
keep if catagoryofroads == "Total"
drop catagoryofroads

* Dropping blank packages and duplicates
drop if package == "" | package == "-" | package == "#REF!" | package == "NIL"
duplicates drop

destring, replace
compress
save `StatewiseSanctions', replace

**************** DELAYED EXECUTION  ***********************
*********************************************************

insheet using Data/Website/DelayedExecution.csv, clear

drop noofroadscompletedlessthanorequa

* Renames
rename sanctionyear sanction_year
rename noofroadscompletedmorethan12mont roads_completed_late
rename totalnoofroadscompleted completed_road_count
rename totalnoofroads cleared_road_count

* Dropping blank packages and duplicates
drop if package == "" | package == "-" | package == "#REF!" | package == "NIL"
duplicates drop

destring, replace
compress
save `DelayedExecution', replace

*************** DELAYED WORK AWARDING ********************
*********************************************************

insheet using Data/Website/DelayedWorkAwarding.csv, clear

drop roadawardedbeforeor150days

* Renames
rename sanctionyear sanction_year
rename totalnoofroads sanctioned_road_count
rename noofroadscleared cleared_road_count
rename roadawardedmorethan150days roads_awarded_late

drop if roads_awarded_late > sanctioned_road_count

* Dropping blank packages and duplicates
drop if package == "" | package == "-" | package == "#REF!" | package == "NIL"
duplicates drop

destring, replace
compress
save `DelayedWorkAwarding', replace

**************** QUALITY MONITORING ***********************
*********************************************************

insheet using Data/Website/QualityMonitoring.csv, names clear

* Renames
rename nameofnqm monitor_name
rename sanctionyear sanction_year
rename grade quality_grade
rename statusofroadatthetimeofinspectio completion_status_at_inspect 

* Convert to STATA dates and change odd values to missing
gen inspection_date = date(inspectiondate, "DMY")
format %td inspection_date
drop inspectiondate
replace inspection_date = . if inspection_date == 0 | inspection_date < td(01jan2000)

* Dropping blank packages and duplicates
drop if package == "" | package == "-" | package == "#REF!" | package == "NIL"
duplicates drop

replace quality_grade = "0" if quality_grade == "U"
replace quality_grade = "1" if quality_grade == "S"
replace completion_status_at_inspect = "0" if completion_status_at_inspect == "P"
replace completion_status_at_inspect = "1" if completion_status_at_inspect == "C"
destring quality_grade completion_status_at_inspect, replace

by sanction_year package (inspection_date), sort: gen stub = _n
reshape wide inspection_date monitor_name quality_grade completion_status_at_inspect, i(sanction_year package) j(stub)

destring, replace
compress
save `QualityMonitoring', replace


*********************************************************
*********** INDIA BIDDING PREP *****************************
*********************************************************

******************* AP1 BIDDING DATA ***********************
*********************************************************

insheet using Data/Bidding/AP1.csv, clear

gen bidding_data_source = 1

gen package = packageno
rename packageno bidding_package
rename biddsreceived total_bids
rename bidstechnicallyqualified qualified_bids
rename estcost estimated_cost
rename noofworks sanctioned_road_count

gen sanction_year = ""
replace sanction_year = "2000-2001" if strmatch(bidding_package, "*I*")
replace sanction_year = "2001-2002" if strmatch(bidding_package, "*II*")
replace sanction_year = "2002-2003" if strmatch(bidding_package, "*III*")
replace sanction_year = "2003-2004" if strmatch(bidding_package, "*IV*")

replace bidding_package = subinstr(bidding_package, " ", "",.)
replace bidding_package = subinstr(bidding_package, "-", "", .)
replace bidding_package = subinstr(bidding_package, "(", "", .)
replace bidding_package = subinstr(bidding_package, ")", "", .)
replace bidding_package = subinstr(bidding_package, "I", "", .)
replace bidding_package = subinstr(bidding_package, "V", "", .)
replace bidding_package = upper(bidding_package)

replace estimated_cost = subinstr(estimated_cost, "Rs.", "", .)
destring estimated_cost, replace float

replace tcv = subinstr(tcv, "Rs.", "", .)
replace tcv = subinstr(tcv, ",", "", .)
replace tcv = subinstr(tcv, " (2nd call)", "", .)
replace tcv = subinstr(tcv, " ", "", .)
replace ecv = subinstr(tcv, " ", "", .)
destring tcv ecv, replace
gen contract_value = tcv
replace contract_value = ecv if contract_value == .
replace contract_value = contract_value/100000 if contract_value > 50000

drop tenderpremiumel tono nf cf ecv tcv state
drop if contract_value == .
drop if total_bids != string(real(total_bids))
destring total_bids, replace
drop if total_bids == . & qualified_bids == .

keep package bidding_package sanction_year total_bids qualified_bids sanctioned_road_count district
duplicates drop
save `AP1', replace

******************* AP2 BIDDING DATA ***********************
*********************************************************

insheet using Data/Bidding/AP2.csv, clear

gen bidding_data_source = 2 

drop if package == ""
drop name_contractor_4 date_nit_4 contract_value_4 v25 v26 v27 state_id
destring, replace

reshape long name_contractor_ date_nit_ contract_value_ bids qualbids amountputtotender, i(state district package)

rename package bidding_package
rename date_nit_ nit_date
rename contract_value_ contract_value
rename bids total_bids
rename qualbids qualified_bids
rename amountputtotender estimated_cost
rename name_contractor_ contractor
drop _j state

drop if total_bids == . & qualified_bids == .
drop if qualified_bids > 100

rename nit_date nit_date_tmp
gen nit_date = date(nit_date_tmp, "DMY")
drop nit_date_tmp
format %td nit_date
replace nit_date = . if nit_date == 0 | nit_date < td(01jan2000)

replace bidding_package = subinstr(bidding_package, " ", "",.)
replace bidding_package = subinstr(bidding_package, "-", "", .)
replace bidding_package = subinstr(bidding_package, "(", "", .)
replace bidding_package = subinstr(bidding_package, ")", "", .)
replace bidding_package = subinstr(bidding_package, "I", "", .)
replace bidding_package = subinstr(bidding_package, "V", "", .)
replace bidding_package = upper(bidding_package)

keep bidding_package district nit_date total_bids qualified_bids
duplicates drop
save `AP2', replace

******************* AP3 BIDDING DATA ***********************
*********************************************************

insheet using Data/Bidding/AP3.csv, clear

gen bidding_data_source = 3

drop nitdate

gen bidding_package = package
rename estcost estimated_cost
rename cv contract_value
rename numberofbids total_bids
rename numberoftechqualifiedbids qualified_bids

replace bidding_package = subinstr(bidding_package, " ", "",.)
replace bidding_package = subinstr(bidding_package, "-", "", .)
replace bidding_package = subinstr(bidding_package, "(", "", .)
replace bidding_package = subinstr(bidding_package, ")", "", .)
replace bidding_package = subinstr(bidding_package, "I", "", .)
replace bidding_package = subinstr(bidding_package, "V", "", .)
replace bidding_package = upper(bidding_package)

replace district = proper(district)
replace district = "Anantapur" if district == "Ananthapur"
replace district = "Visakhapatnam" if district == "Visakhapatanam"

replace estimated_cost = subinstr(estimated_cost, ",", "", .)
replace contract_value = subinstr(contract_value, ",", "", .)
destring estimated_cost contract_value, replace float
replace estimated_cost = round(estimated_cost/100000, 0.01)
replace contract_value = round(contract_value/100000, 0.01)

drop report nameofproject
drop if bidding_package == ""

replace total_bids = "" if mi(real(total_bids))
replace qualified_bids = "" if mi(real(qualified_bids))

destring, replace

drop if total_bids == . & qualified_bids == .

keep package district total_bids qualified_bids
duplicates drop
save `AP3.dta', replace

*******************CG BIDDING DATA ***********************
*********************************************************

insheet using Data/Bidding/CG.csv, clear

rename packageno bidding_package
rename numberofbidsreceived total_bids
rename numberoftechnicallyqualifiedbids qualified_bids
rename sanctionamountconst estimated_cost
rename contractamountconst contract_value

replace bidding_package = subinstr(bidding_package, " ", "",.)
replace bidding_package = subinstr(bidding_package, "-", "", .)
replace bidding_package = subinstr(bidding_package, "(", "", .)
replace bidding_package = subinstr(bidding_package, ")", "", .)
replace bidding_package = subinstr(bidding_package, "I", "", .)
replace bidding_package = subinstr(bidding_package, "V", "", .)
replace bidding_package = upper(bidding_package)

drop if total_bids == . & qualified_bids == .

keep bidding_package total_bids qualified_bids
duplicates drop
save `CG', replace


******************* KN BIDDING DATA ***********************
*********************************************************

insheet using Data/Bidding/KN.csv, clear names

drop state
gen bidding_package = package

replace bidding_package = subinstr(bidding_package, " ", "",.)
replace bidding_package = subinstr(bidding_package, "-", "", .)
replace bidding_package = subinstr(bidding_package, "(", "", .)
replace bidding_package = subinstr(bidding_package, ")", "", .)
replace bidding_package = subinstr(bidding_package, "I", "", .)
replace bidding_package = subinstr(bidding_package, "V", "", .)
replace bidding_package = upper(bidding_package)

rename totalbids total_bids
rename qualifiedbids qualified_bids
rename lengthofroad road_length
rename estimatedcost estimated_cost

drop if total_bids == "dropped"
replace total_bids = subinstr(total_bids, " ", "",.)
replace qualified_bids = subinstr(qualified_bids, " ", "",.)
replace qualified_bids = "0" if qualified_bids == "nil"
destring total_bids qualified_bids, replace

replace road_length = round(road_length, .02)
recast float road_length, force

drop if total_bids == . & qualified_bids == .

keep bidding_package total_bids qualified_bids
duplicates drop
save `KN', replace


******************* UP BIDDING DATA ***********************
*********************************************************

insheet using Data/Bidding/UP.csv, clear

gen state = "UP"

rename date_nit nit_date
rename year sanctionyear
egen total_bids = rownonmiss(bidder_1 bidder_2 bidder_3 bidder_4 bidder_5), s
egen disqualified_bids = rownonmiss(disqualified_1 disqualified_2 disqualified_3 disqualified_4), s
gen qualified_bids = total_bids - disqualified_bids
replace district = proper(district)
replace contract_value = round(contract_value, 10)

gen bidding_package = package
replace bidding_package = subinstr(bidding_package, " ", "",.)
replace bidding_package = subinstr(bidding_package, "-", "", .)
replace bidding_package = subinstr(bidding_package, "(", "", .)
replace bidding_package = subinstr(bidding_package, ")", "", .)
replace bidding_package = subinstr(bidding_package, "I", "", .)
replace bidding_package = subinstr(bidding_package, "V", "", .)
replace bidding_package = upper(bidding_package)

rename nit_date nit_date_tmp
gen nit_date = date(nit_date_tmp, "DMY")
drop nit_date_tmp
format %td nit_date
replace nit_date = . if nit_date == 0 | nit_date < td(01jan2000)

keep package district nit_date total_bids qualified_bids
duplicates drop
save `UP', replace


*********************************************************
*************** WEBSITE MERGE ****************************
*********************************************************

********* Merging AgreementDetails and TenderingDetails************
*********************************************************

** Primary merge on all common vars

* In AgreementDetails, reshape to pool multiple agreement numbers and contract values, create a unique var for dups in 1st merge, and gen a marker for this dataset
use `AgreementDetails', clear
** This package is 'too wide'
drop if package == "OR1712"
bysort district sanction_year package nit_number contract_date completiondue_date agreement_date contractor contractor_id (agreement_number): gen j = _n
reshape wide agreement_number contract_value, i(district sanction_year package nit_number contract_date completiondue_date agreement_date contractor contractor_id) j(j)
duplicates tag sanction_year package district contractor nit_number contract_date agreement_date, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup
gen AgreementDetailsMarker = _n
save `AgreementDetails', replace

* In TenderingDetails, create a unique var for dups in 1st merge  and a marker for this dataset
use `TenderingDetails', clear
duplicates tag sanction_year package district contractor nit_number contract_date agreement_date, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup
gen TenderingDetailsMarker = _n

* Perform 1st merge, create a marker for successful merges, and drop unmerged AgreementDetails obs
merge package sanction_year district contractor nit_number contract_date agreement_date unique using `AgreementDetails', sort update
gen merged = (_merge==3)
drop if _merge == 2
drop _merge unique

** Merge correcting for missing sanction_year

* Create a dummy for missing sanction_year and a unique var for dups in next merge
gen sanction_year_missing = 1 if sanction_year == ""
duplicates tag sanction_year_missing package district contractor nit_number contract_date agreement_date, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

* In AgreementDetails, drop old unique var, create a dummy always = 1, empty merged var, and unique var for dups in next merge
use `AgreementDetails', clear
drop unique
gen sanction_year_missing = 1
gen merged = 0
duplicates tag sanction_year_missing package district contractor nit_number contract_date agreement_date, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

* Perform next merge, update marker for successful merges, and drop unmerged AgreementDetails obs
merge package sanction_year_missing district contractor nit_number contract_date agreement_date unique merged using `MergeInProcess', sort update
replace merged = 1 if _merge == 3
drop if _merge == 1
drop _merge unique sanction_year_missing

** Merge correcting for missing contractor

* Create dummy for missing contractor and unique var for dups in next merge
gen contractor_missing = 1 if contractor == ""
duplicates tag sanction_year package district contractor_missing nit_number contract_date agreement_date, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

* In AgreementDetails, drop old unique var, create dummy always =1, and unique var for next merge
use `AgreementDetails', clear
drop unique
gen contractor_missing = 1
gen merged = 0
duplicates tag sanction_year package district contractor_missing nit_number contract_date agreement_date, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

* Perform next merge, update marker for successful merges, and drop unsuccessful AgreementDetails obs
merge package sanction_year district contractor_missing nit_number contract_date agreement_date unique merged using `MergeInProcess', sort update
replace merged = 1 if _merge == 3
drop if _merge == 1
drop _merge unique contractor_missing

** Merge correcting for missing contract_date

* Create dummy for missing contract_date and unique var for dups in next merge
gen contract_date_missing = 1 if contract_date == .
duplicates tag sanction_year package district contractor nit_number contract_date_missing, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

* In AgreementDetails, drop old unique var, create dummy always =1, and unique var for next merge
use `AgreementDetails', clear
drop unique
gen contract_date_missing = 1
gen merged = 0
duplicates tag sanction_year package district contractor nit_number contract_date_missing, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

* Perform next merge, update marker for successful merges, and drop unsuccessful AgreementDetails obs
merge sanction_year package district contractor nit_number contract_date_missing agreement_date unique merged using `MergeInProcess', sort update
replace merged = 1 if _merge == 3
drop if _merge == 1
drop _merge unique contract_date_missing

** Merge correcting for missing agreement_date

* Create dummy for missing agreement_date and unique var for dups in next merge
gen agreement_date_missing = 1 if agreement_date == .
duplicates tag sanction_year package district contractor nit_number contract_date agreement_date_missing, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

* In AgreementDetails, drop old unique var, create dummy always =1, and unique var for next merge
use `AgreementDetails', clear
drop unique
gen agreement_date_missing = 1
gen merged = 0
duplicates tag sanction_year package district contractor nit_number contract_date agreement_date_missing, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

* Perform next merge, update marker for successful merges, and drop unsuccessful AgreementDetails obs
merge sanction_year package district contractor nit_number contract_date agreement_date_missing unique merged using `MergeInProcess', sort update
replace merged = 1 if _merge == 3
drop if _merge == 1
drop _merge unique agreement_date_missing

** Merge correcting for missing contract_date and agreement_date

* Create dummy for missing contract_date and agreement_date and unique var for dups in next merge
gen contract_date_missing = 1 if contract_date == .
gen agreement_date_missing = 1 if agreement_date == .
duplicates tag sanction_year package district contractor nit_number contract_date_missing agreement_date_missing, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

* In AgreementDetails, drop old unique var, create dummy always =1, and unique var for next merge
use `AgreementDetails', clear
drop unique
gen contract_date_missing = 1
gen agreement_date_missing = 1
gen merged = 0
duplicates tag sanction_year package district contractor nit_number contract_date_missing agreement_date_missing, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

* Perform next merge, update marker for successful merges, and drop unsuccessful AgreementDetails obs
merge sanction_year package district contractor nit_number contract_date_missing agreement_date_missing unique merged using `MergeInProcess', sort update
replace merged = 1 if _merge == 3
drop if _merge == 1
drop _merge unique contract_date_missing agreement_date_missing

** Merge correcting for missing contractor and agreement_date

* Create dummy for missing contractor and agreement_date and unique var for dups in next merge
gen contractor_missing = 1 if contractor == ""
gen agreement_date_missing = 1 if agreement_date == .
duplicates tag sanction_year package district contractor_missing nit_number contract_date agreement_date_missing, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

* In AgreementDetails, drop old unique var, create dummy always =1, and unique var for next merge
use `AgreementDetails', clear
drop unique
gen contractor_missing = 1
gen agreement_date_missing = 1
gen merged = 0
duplicates tag sanction_year package district contractor_missing nit_number contract_date agreement_date_missing, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

* Perform next merge, update marker for successful merges, and drop unsuccessful AgreementDetails obs
merge sanction_year package district contractor_missing nit_number contract_date agreement_date_missing unique merged using `MergeInProcess', sort update
replace merged = 1 if _merge == 3
drop if _merge == 1
drop _merge unique contractor_missing agreement_date_missing

** Merge correcting for missing contractor, contract_date, and agreement_date

* Create dummy for missing contractor, contract_date, and agreement_date and unique var for dups in next merge
gen contractor_missing = 1 if contractor == ""
gen contract_date_missing = 1 if contract_date == .
gen agreement_date_missing = 1 if agreement_date == .
duplicates tag sanction_year package district contractor_missing nit_number contract_date_missing agreement_date_missing, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

* In AgreementDetails, drop old unique var, create dummy always =1, and unique var for next merge
use `AgreementDetails', clear
drop unique
gen contractor_missing = 1
gen contract_date_missing = 1
gen agreement_date_missing = 1
gen merged = 0
duplicates tag sanction_year package district contractor_missing nit_number contract_date_missing agreement_date_missing, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

* Perform next merge, update marker for successful merges, and drop unsuccessful AgreementDetails obs
merge sanction_year package district contractor_missing nit_number contract_date_missing agreement_date_missing unique merged using `MergeInProcess', sort update
replace merged = 1 if _merge == 3
drop if _merge == 1
drop _merge unique contractor_missing agreement_date_missing contract_date_missing

** Wrap-up

* Add all AgreementDetails obs and drop those already merged
append using `AgreementDetails'
bysort AgreementDetailsMarker: drop if _N > 1 & merged == .
drop unique merged

* Reshape to unpool contract values (leaving agreement numbers pooled) and drop obs which have contract values missing but not those which simply didn't match
gen i = _n
reshape long contract_value, i(i)
drop if missing(contract_value) & _j != 1
drop i _j

* If one variable is missing and there are one or more indentical observations which all agree on the missing variable as a single value, use that value to fill in the missing variable
unab all : _all
local exceptions = "nit_number AgreementDetailsMarker TenderingDetailsMarker"
local all_nonmarkers : list all - exceptions
foreach var in `all_nonmarkers' {
	local shortlist : list all_nonmarkers - var
	gen missing = mi(`var')
	bysort `shortlist' missing (`var'): gen agreement = (`var'[1] == `var'[_N])
	by `shortlist': replace `var' = `var'[1] if mi(`var') & !mi(`var'[1]) & agreement[1] == 1
	drop missing agreement
}

* Drop duplicates in terms of all non-marker vars (arbitrarily keeps one marker)
unab all : _all
local markers = "AgreementDetailsMarker TenderingDetailsMarker"
local all_nonmarkers : list all - markers
duplicates drop `all_nonmarkers', force

* Save as MergeInProcess
save `MergeInProcess', replace

******* Merging MergeInProcess and WorkAwardDetailsMain*************
*********************************************************

** Primary merge on all common vars

* In WorkAwardDetailsMain, create a unique var for dups in 1st merge and a marker for this dataset
use `WorkAwardDetailsMain', clear
duplicates tag sanction_year package district nit_date company contract_value contract_date completiondue_date, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup
gen WorkAwardDetailsMainMarker = _n
save `WorkAwardDetailsMain', replace

* In MergeInProcess, reshape to pool multiple nit numbers and markers (eliminating missing companies), arbitrarily pick markers to keep when there are multiple, and create a unique var for dups in 1st merge
use `MergeInProcess', clear
egen i = group(district sanction_year package contract_date completiondue_date agreement_date contractor contractor_id contract_value company agreement_number* nit_date), missing
bysort district sanction_year package contract_date completiondue_date agreement_date contractor contractor_id contract_value company agreement_number* nit_date: gen j = _n
rename AgreementDetailsMarker AgreementDetailsMarker_temp
rename TenderingDetailsMarker TenderingDetailsMarker_temp
reshape wide nit_number AgreementDetailsMarker_temp TenderingDetailsMarker_temp, i(i) j(j)
egen AgreementDetailsMarker = rowfirst(AgreementDetailsMarker_temp*)
egen TenderingDetailsMarker = rowfirst(TenderingDetailsMarker_temp*)
drop TenderingDetailsMarker_temp* AgreementDetailsMarker_temp*
duplicates tag sanction_year package district nit_date company contract_value contract_date completiondue_date, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup i

* Perform 1st merge, create a marker for successful merges, and drop unmerged WorkAwardDetailsMain obs
merge sanction_year package district nit_date company contract_value contract_date completiondue_date unique using `WorkAwardDetailsMain', sort update
gen merged = (_merge==3)
drop if _merge == 2
drop _merge unique

** Merge correcting for missing nit_date

* Create a dummy for missing nit_date and a unique var for dups in next merge
gen nit_date_missing = 1 if nit_date == .
duplicates tag sanction_year package district nit_date_missing company contract_value contract_date completiondue_date, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

* In WorkAwardDetailsMain, drop old unique var, create a dummy always = 1, empty merged var, and unique var for dups in next merge
use `WorkAwardDetailsMain', clear
drop unique
gen nit_date_missing = 1
gen merged = 0
duplicates tag sanction_year package district nit_date_missing company contract_value contract_date completiondue_date, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

* Perform next merge, update marker for successful merges, and drop unmerged WorkAwardDetailsMain obs
merge sanction_year package district nit_date_missing company contract_value contract_date completiondue_date unique merged using `MergeInProcess', sort update
replace merged = 1 if _merge == 3
drop if _merge == 1
drop _merge unique nit_date_missing

** Merge correcting for missing company

* Create a dummy for missing company and a unique var for dups in next merge
gen company_missing = 1 if company == ""
duplicates tag sanction_year package district nit_date company_missing contract_value contract_date completiondue_date, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

* In WorkAwardDetailsMain, drop old unique var, create a dummy always = 1, empty merged var, and unique var for dups in next merge
use `WorkAwardDetailsMain', clear
drop unique
gen company_missing = 1
gen merged = 0
duplicates tag sanction_year package district nit_date company_missing contract_value contract_date completiondue_date, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

* Perform next merge, update marker for successful merges, and drop unmerged WorkAwardDetailsMain obs
merge sanction_year package district nit_date company_missing contract_value contract_date completiondue_date unique merged using `MergeInProcess', sort update
replace merged = 1 if _merge == 3
drop if _merge == 1
drop _merge unique company_missing

** Merge correcting for missing contract_value

* Create a dummy for missing contract_value and a unique var for dups in next merge
gen contract_value_missing = 1 if contract_value == .
duplicates tag sanction_year package district nit_date company contract_value_missing contract_date completiondue_date, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

* In WorkAwardDetailsMain, drop old unique var, create a dummy always = 1, empty merged var, and unique var for dups in next merge
use `WorkAwardDetailsMain', clear
drop unique
gen contract_value_missing = 1
gen merged = 0
duplicates tag sanction_year package district nit_date company contract_value_missing contract_date completiondue_date, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

* Perform next merge, update marker for successful merges, and drop unmerged WorkAwardDetailsMain obs
merge sanction_year package district nit_date company contract_value_missing contract_date completiondue_date unique merged using `MergeInProcess', sort update
replace merged = 1 if _merge == 3
drop if _merge == 1
drop _merge unique contract_value_missing

** Merge correcting for missing company and nit_date

* Create a dummy for missing company and missing nit_date and a unique var for dups in next merge
gen company_missing = 1 if company == ""
gen nit_date_missing = 1 if nit_date == .
duplicates tag sanction_year package district nit_date_missing company_missing contract_value contract_date completiondue_date, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

* In WorkAwardDetailsMain, drop old unique var, create two dummies always = 1, empty merged var, and unique var for dups in next merge
use `WorkAwardDetailsMain', clear
drop unique
gen company_missing = 1
gen nit_date_missing = 1
gen merged = 0
duplicates tag sanction_year package district nit_date_missing company_missing contract_value contract_date completiondue_date, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

* Perform next merge, update marker for successful merges, and drop unmerged WorkAwardDetailsMain obs
merge sanction_year package district nit_date_missing company_missing contract_value contract_date completiondue_date unique merged using `MergeInProcess', sort update
replace merged = 1 if _merge == 3
drop if _merge == 1
drop _merge unique company_missing nit_date_missing

** Merge correcting for missing contract_value and nit_date

* Create a dummy for missing company and missing nit_date and a unique var for dups in next merge
gen contract_value_missing = 1 if contract_value == .
gen nit_date_missing = 1 if nit_date == .
duplicates tag sanction_year package district nit_date_missing company contract_value_missing contract_date completiondue_date, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

* In WorkAwardDetailsMain, drop old unique var, create two dummies always = 1, empty merged var, and unique var for dups in next merge
use `WorkAwardDetailsMain', clear
drop unique
gen contract_value_missing = 1
gen nit_date_missing = 1
gen merged = 0
duplicates tag sanction_year package district nit_date_missing company contract_value_missing contract_date completiondue_date, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

* Perform next merge, update marker for successful merges, and drop unmerged WorkAwardDetailsMain obs
merge sanction_year package district nit_date_missing company contract_value_missing contract_date completiondue_date unique merged using `MergeInProcess', sort update
replace merged = 1 if _merge == 3
drop if _merge == 1
drop _merge unique contract_value_missing nit_date_missing

** Wrap-up

* Add all WorkAwardDetailsMain obs and drop those already merged
append using `WorkAwardDetailsMain'
bysort WorkAwardDetailsMainMarker: drop if _N > 1 & merged == .
drop unique merged

* If one variable is missing and there are one or more indentical observations which all agree on the missing variable as a single value, use that value to fill in the missing variable
unab all : _all
local exceptions = "nit_number AgreementDetailsMarker TenderingDetailsMarker"
local all_nonmarkers : list all - exceptions
foreach var in `all_nonmarkers' {
	local shortlist : list all_nonmarkers - var
	gen missing = mi(`var')
	bysort `shortlist' missing (`var'): gen agreement = (`var'[1] == `var'[_N])
	by `shortlist': replace `var' = `var'[1] if mi(`var') & !mi(`var'[1]) & agreement[1] == 1
	drop missing agreement
}

* Drop duplicates in terms of all non-marker vars (arbitrarily keeps one marker)
unab all : _all
local markers = "AgreementDetailsMarker TenderingDetailsMarker WorkAwardDetailsMainMarker"
local all_nonmarkers : list all - markers
duplicates drop `all_nonmarkers', force

* Save as MergeInProcess
save `MergeInProcess', replace

****** Merging MergeInProcess and WorkAwardPopups*****************
*********************************************************

** First joinby

* In WorkAwardPopups, create a dummy var that =1 if there dups for joinby and a marker for this dataset
use `WorkAwardPopups', clear
duplicates tag sanction_year package work_value payment, g(dup)
gen unique = (dup > 0)
drop dup
gen WorkAwardPopupsMarker = _n
save `WorkAwardPopups', replace

* In MergeInProcess, create a dummy var that =0 always
use `MergeInProcess', clear
gen unique = 0

* Perform joinby
joinby sanction_year package work_value payment unique using `WorkAwardPopups', unmatched(master) update
gen merged = (_merge == 3)
drop _merge

** Second joinby correcting for differing work_value and payment (these are higher in MergeInProcess and so are taken to be more current)

* Create contrant variable in MergeInProcess
replace unique = 0

* Save as MergeInProcess
save `MergeInProcess', replace

* In WorkAwardPopups, create dummy var that =1 if there dups and create empty merged variable
use `WorkAwardPopups', clear
duplicates tag sanction_year package, g(dup)
replace unique = (dup > 0)
gen merged = 0
drop dup

* Perform joinby
joinby sanction_year package unique merged using `MergeInProcess', unmatched(using) update replace
drop _merge

** Wrap-up

* Add all WorkAwardDetailsMain obs and drop those already merged
append using `WorkAwardPopups'
bysort WorkAwardPopupsMarker: drop if _N > 1 & merged == .
drop unique merged

* Save as MergeInProcess
save `MergeInProcess', replace

****** Merging MergeInProcess and StatewiseSanctions****************
*********************************************************

* In StatewiseSanctions, create a dummy var that =1 if there dups for joinby and a marker for this dataset
use `StatewiseSanctions', clear
duplicates tag sanction_year package estimated_cost_less_protect, g(dup)
gen unique = (dup > 0)
drop dup
gen StatewiseSanctionsMarker = _n
save `StatewiseSanctions', replace

* In MergeInProcess, create a dummy var that =0 always
use `MergeInProcess', clear
gen unique = 0

* Perform joinby
joinby sanction_year package estimated_cost_less_protect unique using `StatewiseSanctions', unmatched(both) update
drop _merge unique

*************** possible improvements: fix differences in contract_value and road_length

* Save as MergeInProcess
save `MergeInProcess', replace

****** Merging MergeInProcess and DelayedExecution******************
*********************************************************

** Primary joinby on all common vars

* In DelayedExecution, create a dummy var that =1 if there dups for joinby and a marker for this dataset
use `DelayedExecution', clear
duplicates tag sanction_year package district cleared_road_count completed_road_count, g(dup)
gen unique = (dup > 0)
drop dup
gen DelayedExecutionMarker = _n
save `DelayedExecution', replace

* In MergeInProcess, create a dummy var that =0 always
use `MergeInProcess', clear
gen unique = 0

* Perform joinby
joinby sanction_year package district cleared_road_count completed_road_count unique using `DelayedExecution', unmatched(both) update
gen merged = (_merge == 3)
drop if _merge == 2
drop _merge unique

** Merge correcting for sanctions without contracts (did not match with data containing district and therefore does not match with DelayedExecution)

* Create a unique var for dups in merge
duplicates tag sanction_year package cleared_road_count, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

* In DelayedExecution, create unique var for dup in merge
use `DelayedExecution', clear
drop unique
gen merged = 0
duplicates tag sanction_year package cleared_road_count, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

* Perform merge
merge sanction_year package cleared_road_count unique merged using `MergeInProcess', sort
replace merged = 1 if _merge == 3
drop if _merge == 1
drop _merge unique

** Wrap-up

* Add all DelayedExecution obs and drop those already merged
append using `DelayedExecution'
bysort DelayedExecutionMarker: drop if _N > 1 & merged == .
drop unique merged

* Save as MergeInProcess
save `MergeInProcess', replace

****** Merging MergeInProcess and DelayedWorkAwarding***************
*********************************************************

* In DelayedWorkAwarding, create a dummy var that =1 if there dups for joinby and a marker for this dataset
use `DelayedWorkAwarding', clear
duplicates tag sanction_year package district sanctioned_road_count cleared_road_count, g(dup)
gen unique = (dup > 0)
drop dup
gen DelayedWorkAwardingMarker = _n
save `DelayedWorkAwarding', replace

* In MergeInProcess, create a dummy var that =0 always
use `MergeInProcess', clear
gen unique = 0

* Perform joinby
joinby sanction_year package district sanctioned_road_count cleared_road_count unique using `DelayedWorkAwarding', unmatched(both) update
drop _merge unique

* Save as MergeInProcess
save `MergeInProcess', replace

****** Merging MergeInProcess and QualityMonitoring******************
*********************************************************

* In QualityMonitoring, create a dummy var that =1 if there dups for joinby and a marker for this dataset
use `QualityMonitoring', clear
duplicates tag sanction_year package, g(dup)
gen unique = (dup > 0)
drop dup
gen QualityMonitoringMarker = _n
save `QualityMonitoring', replace

* In MergeInProcess, create a dummy var that =0 always
use `MergeInProcess', clear
gen unique = 0

* Perform joinby
joinby sanction_year package unique using `QualityMonitoring', unmatched(both) update
drop _merge unique

* Save as MergeInProcess
save `MergeInProcess', replace


****** Merge Success Stats *************************************
*********************************************************

gen success = !mi(WorkAwardDetailsMainMarker) + !mi(TenderingDetailsMarker) + !mi(AgreementDetailsMarker) + !mi(WorkAwardPopupsMarker) /*
*/ + !mi(StatewiseSanctionsMarker) + !mi(DelayedExecutionMarker) + !mi(DelayedWorkAwardingMarker) + !mi(QualityMonitoringMarker)

tab success

keep if ( !mi(WorkAwardDetailsMainMarker) & !mi(AgreementDetailsMarker) & !mi(TenderingDetailsMarker) & !mi(WorkAwardPopupsMarker) & /*
 */ !mi(StatewiseSanctionsMarker) ) | !mi(StatewiseSanctionsMarker)

gen FiveSetMarker = ( !mi(WorkAwardDetailsMainMarker) & !mi(AgreementDetailsMarker) & !mi(TenderingDetailsMarker) & !mi(WorkAwardPopupsMarker) & /*
 */ !mi(StatewiseSanctionsMarker) )
 
di _N
count if FiveSetMarker
count if !mi(contractor_id) & FiveSetMarker
count if !mi(nit_date) & FiveSetMarker
count if !mi(DelayedExecutionMarker) & FiveSetMarker
count if !mi(DelayedWorkAwardingMarker) & FiveSetMarker
count if !mi(QualityMonitoringMarker) & FiveSetMarker

drop *Marker success


*********************************************************
*************** INDIA BIDDING MERGE ***********************
*********************************************************

****** Merging MergeInProcess and AP1****************************
*********************************************************

gen bidding_package = package
replace bidding_package = subinstr(bidding_package, " ", "",.)
replace bidding_package = subinstr(bidding_package, "-", "", .)
replace bidding_package = subinstr(bidding_package, "(", "", .)
replace bidding_package = subinstr(bidding_package, ")", "", .)
replace bidding_package = subinstr(bidding_package, "I", "", .)
replace bidding_package = subinstr(bidding_package, "V", "", .)
replace bidding_package = upper(bidding_package)

duplicates tag sanction_year bidding_package district, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

use `AP1', clear
duplicates tag sanction_year bidding_package district, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

merge sanction_year bidding_package district unique using `MergeInProcess', sort update replace
drop if _merge == 1
gen merged = (_merge > 2)
drop _merge unique

** Merge over another group of variables, correcting for missing sanction_year

gen sanction_year_missing = 1
duplicates tag sanction_year_missing bidding_package district sanctioned_road_count, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

use `AP1', clear
gen merged = 0
gen sanction_year_missing = mi(sanction_year)
duplicates tag sanction_year_missing bidding_package district sanctioned_road_count, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

merge sanction_year_missing bidding_package district sanctioned_road_count unique merged using `MergeInProcess', sort update replace
drop if _merge == 1
replace merged = 1 if _merge > 3
drop _merge unique merged sanction_year_missing

****** Merging MergeInProcess and AP2 ****************************
*********************************************************

duplicates tag bidding_package district nit_date, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

use `AP2', clear
duplicates tag bidding_package district nit_date, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

merge bidding_package district nit_date unique using `MergeInProcess', sort update replace
drop _merge unique


****** Merging MergeInProcess and AP3 ****************************
*********************************************************

duplicates tag package district, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

use `AP3', clear
duplicates tag package district, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

merge package district unique using `MergeInProcess', sort update replace
drop if _merge == 1
drop _merge unique


****** Merging MergeInProcess and CG  ****************************
*********************************************************

duplicates tag bidding_package, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

use `CG', clear
duplicates tag bidding_package, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

merge bidding_package unique using `MergeInProcess', sort update replace
drop if _merge == 1
drop _merge unique


****** Merging MergeInProcess and KN  ****************************
*********************************************************

duplicates tag bidding_package, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

use `KN', clear
duplicates tag bidding_package, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

merge bidding_package unique using `MergeInProcess', sort update replace
drop if _merge == 1
drop _merge unique


****** Merging MergeInProcess and UP  ****************************
*********************************************************

duplicates tag package district nit_date, g(dup)
gen unique = string(_n) + "a" if dup > 0
drop dup

* Save as MergeInProcess
save `MergeInProcess', replace

use `UP', clear
duplicates tag package district nit_date, g(dup)
gen unique = string(_n) + "b" if dup > 0
drop dup

merge package district nit_date unique using `MergeInProcess', sort update replace
drop _merge unique


* Save as MergedDataset
compress
save MergedDataset.dta, replace

