#delimit ;

version 9.0;

set seed 973198136 ;

cap prog drop runme ;
prog def runme ;

local hypothesis = `1' ;
tempfile main bootsave ;

use "Coded Dataset - Contract Level.dta", clear ;
*use collapsed ;
/* 	hasinsurance - LHS var, fraction with insurance
	selfemployed - 0/1 dummmy var for self employed
	post - 0/1 dummy var for after policy
	eproc - interaction of post and self
*/

di ;
xi: reg `2' eproc log_estimated_cost log_road_length i.state_id i.nit_year, cluster(state_id) ;
global mainbeta = _b[eproc] ;
global maint = (_b[eproc] - `hypothesis') / _se[eproc] ;
predict epshat , resid;
predict yhat , xb ;

/* also generate "impose the null hypothesis" yhat and residual */
gen temp_y = `2' - eproc * `hypothesis' ;
xi: reg temp_y log_estimated_cost log_road_length i.state_id i.nit_year ;
predict epshat_imposed , resid ;
predict yhat_imposed , xb ;
qui replace yhat_imposed = yhat_imposed + eproc * `hypothesis' ;

sort state_id log_estimated_cost ;
qui save `main' , replace ;

qui by state_id: keep if _n == 1 ;
qui summ ;
global numyears = r(N) ;

cap erase `bootsave' ;
qui postfile bskeep beta_np t_np t_fixx t_wild
	using `bootsave' , replace ; 

forvalues b = 1/$bootreps { ;

/* first do wild bootstrap */
use `main', replace ;
qui by state_id: gen temp = uniform() ;
qui by state_id: gen pos = (temp[1] < .5) ;
/*  these two lines (and commendted t-stat below
are if you don't want to impose the null hypothesis*/
/*
gen wildresid = epshat * (2*pos - 1) ;
gen wildy = yhat + wildresid ;
*/
qui gen wildresid = epshat_imposed * (2*pos - 1) ;
qui gen wildy = yhat_imposed + wildresid ;
qui reg wildy eproc log_estimated_cost log_road_length _I*, cluster(state_id) ;
local bst_wild = (_b[eproc] - `hypothesis') / _se[eproc] ;
*local bst_wild = (_b[eproc] - $mainbeta) / _se[eproc] ;

post bskeep ( 0 ) ( 0 ) ( 0 ) (`bst_wild') ;
} ; /* end of bootstrap reps */
qui postclose bskeep ;

qui drop _all ;
qui set obs 1 ;
gen t_np = $maint ;
gen t_fixx = $maint ;
gen t_wild = $maint ;
qui append using `bootsave' ;

qui gen n = . ;
foreach stat in t_np t_fixx t_wild { ;
qui summ `stat' ;
local bign = r(N) ;
sort `stat' ;
qui replace n = _n ;
qui summ n if abs(`stat' - $maint) < .000001 ;
local myp = r(mean) / `bign' ;
global pctile_`stat' = 2 * min(`myp',(1-`myp')) ;
} ;

global mainp = norm($maint) ;
global pctile_main = 2 * min($mainp,(1-$mainp)) ;

local myfmt = "%7.5f" ;

di ; di "Number BS reps = $bootreps, Null hypothesis = `hypothesis'" ;
display "Main beta" _column(13) "main T"	_column(22) "Main %le"
	_column(33) "NP BS %le" _column(44) "fixX %le" _column(54) "wild %le" ;
di 	%6.3f $mainbeta _column(13) %6.3f $maint  _column(23) 
	`myfmt' $pctile_main _column(34) `myfmt' $pctile_t_np 
	_column(44) `myfmt' $pctile_t_fixx
	_column(55) `myfmt' $pctile_t_wild ;
	
file open exportf using Table3Panel1Column4PValue.txt, replace write ;
file write exportf "$pctile_t_wild" ;
file close exportf ;

end ;


global bootreps = 999 ;
use "Coded Dataset - Contract Level.dta", clear ;
xi: reg total_bids eproc log_estimated_cost log_road_length i.state_id i.nit_year, robust ;
runme 0 total_bids ;

*Table3Panel1Column4PValue.csv

version 10

