clear all
clear all
set matsize 11000
set maxvar 11000
set more off
cd/


local setpath "SET PATH"
local dir "`setpath'/Eproc_Indo/DTA Files"

cd "`dir'"

*Note that first_stage_a takes a few hours to run and first_stage_b takes roughly 1 day to run
*If says that system not responding, is not from an error, leave until completes
local first_stage_a = 1
local first_stage_b = 1
local second_stage = 1
	
	
if `first_stage_a' == 1{	
	
	use "z_all_firm_table", clear

	**Identifying winner firm
	gen x = (z_pemlel_fin_group_enc == 1)
	keep if x == 1
	drop if firmnamerev == ""
	sort firmnamerev
	keep z_uniq_pid firmnamerev x
	duplicates drop
	
	sort firmnamerev
	egen fc = group(firmnamerev)
	egen n = max(fc)
	local n = n 
	display `n'
	gen win_f = fc

	duplicates tag z_uniq_pid, gen(tag)
	drop if tag > 0
	drop tag
	drop firmnamerev


	quie reshape wide x, i(z_uniq_pid) j(fc)
	foreach y of varlist x1-x`n'{
		quie replace `y' = 0 if `y' == .
	}
	
	sort z_uniq_pid
	save firm_codes_konsultan, replace
}	

if `first_stage_b' == 1{	

	use "z_all_project_table", clear
	cap drop _merge

	
	merge z_uniq_pid using firm_codes_konsultan, sort
	tab _merge
	keep if _merge == 3
	drop _merge
	
	
	egen state_firm = group(z_state_num win_f)	
	save firmFE_output_start, replace
	

	local start = 1
	foreach v in lnfinalnegobid{
		if "`v'" == "lnfinalnegobid"{
			local contr "lnpagudana"
			local str "lnf"	
		}
				
		foreach k of numlist 0 1{
			use firmFE_output_start, clear
					
			if `k' == 0{
				local pr_t = "works"
			}	
			if `k' == 1{
				local pr_t = "kons"
			}
	
			
			gen winner_`str'_b_`pr_t' = .
			gen winner_`str'_se_`pr_t' = .
			
			**Two-way clustered SEs
			disp "`v'"
			reg `v' sep eproc_on x* y2005 y2006 y2007 y2008 i.z_state_num `contr' if z_konsultan == `k', cluster(z_state_num)
			matrix v1 = e(V)
			
			reg `v' sep eproc_on x* y2005 y2006 y2007 y2008 i.z_state_num `contr' if z_konsultan == `k', cluster(win_f)
			matrix v2 = e(V)
			
			reg `v' sep eproc_on x* y2005 y2006 y2007 y2008 i.z_state_num `contr' if z_konsultan == `k', cluster(state_firm)
			matrix v3 = e(V)
			tempvar sample 
			g `sample' = (e(sample) == 1)						
			
			matrix b = e(b)
			local obs = r(N)
			matrix v4 = v1 + v2 - v3
			matrix vnew = v4
			matrix bnew = b		
			ereturn post bnew vnew, depname(`v') obs(`obs') esample(`sample')
					
			local n = n
			forvalues y = 1/`n'{
				cap quie replace winner_`str'_b_`pr_t' = _b[x`y'] if win_f == `y'
				cap quie replace winner_`str'_se_`pr_t' = _se[x`y'] if win_f == `y'
			}

			replace winner_`str'_b_`pr_t' = . if z_konsultan != `k'
			
			keep z_uniq_pid winner_* win_f state_firm z_state_num
			
	
			if `start' == 1{
				save firmFE_estimates, replace
			}
			if `start' == 0{
				merge 1:1 z_uniq_pid using firmFE_estimates
				drop _merge 
				save firmFE_estimates, replace
			}
			
			local start = 0
		}
	}
}	

	
if `second_stage' == 1{		

	use firmFE_estimates, clear
	merge 1:1 z_uniq_pid using z_all_project_table, gen(_m2)
	drop if _m2 == 2
	drop _m*
	merge 1:1 z_uniq_pid using firm_codes_konsultan
	drop _m*
	
	gen var_name = ""
	gen var_b = .
	gen var_se = .
	gen var_pval = .
	gen var_obs_num = .
	
	local varlist "lnfinalnegobid"
	local row = 1
	foreach v in `varlist'{
		foreach k of numlist 0 1{			
			if `k' == 0{
				local pr_t = "works"
			}	
			if `k' == 1{
				local pr_t = "kons"
			}		
	
			if "`v'" == "lnpagudana"{
				local contr ""
				local str "lnp"		
			}
			if "`v'" == "lnfinalnegobid"{
				local contr "lnpagudana"
				local str "lnf"			
			}
		
			xi: ivreg2 winner_`str'_b_`pr_t' (sep = eproc_on) y2005 y2006 y2007 y2008 `contr' i.z_state_num if z_konsultan == `k' `cond' [aw=1/winner_`str'_se_`pr_t'^2], cluster(z_state_num) ffirst partial(i.z_state_num)
		
			matrix v1 = e(V)	
			xi: ivreg2 winner_`str'_b_`pr_t' (sep = eproc_on) y2005 y2006 y2007 y2008 `contr' i.z_state_num if z_konsultan == `k' `cond' [aw=1/winner_`str'_se_`pr_t'^2], cluster(win_f) ffirst partial(i.z_state_num)
			matrix v2 = e(V)	
			xi: ivreg2 winner_`str'_b_`pr_t' (sep = eproc_on) y2005 y2006 y2007 y2008 `contr' i.z_state_num if z_konsultan == `k' `cond' [aw=1/winner_`str'_se_`pr_t'^2], cluster(state_firm) ffirst partial(i.z_state_num)
			replace var_name = "`v'" in `row'
			replace var_b = _b[sep] in `row'
			replace var_obs_num = e(N) in `row'
			matrix v3 = e(V)
			tempvar sample 
			g `sample' = (e(sample) == 1)	
					
			matrix b = e(b)
			local obs = r(N)
			matrix v4 = v1 + v2 - v3
			matrix vnew = v4
			matrix bnew = b		
			ereturn post bnew vnew, depname(winner_`str'_b_`pr_t') obs(`obs') esample(`sample')			
			ereturn disp
			replace var_se = _se[sep] in `row'
			test _b[sep] == 0
			replace var_pval = r(p) in `row'
			
			local row = `row' + 1
			
		}	
	}
	
	outsheet var_name var_b var_se var_pval var_obs_num in 1/`row' using "../Output/Table5", replace	

}
